#include <cstdio>
#include <iostream>
#include <vector>
#include <algorithm>
#include <set>
using namespace std;

struct point
{
    int x, y;
    point(int x, int y):x(x), y(y){}
    point():point(0, 0){}
};

struct edge
{
    int a, b;
    float distSq;

    edge(int a, int b, float distSq):
        a(a), b(b), distSq(distSq){}
    edge():edge(0, 0, 0){}

    bool operator < (edge e)const {return distSq < e.distSq; }
};

pair<float, float> crossing(point a, point b, point c, point d)
{
    int p = a.x * b.y - a.y * b.x;
    int q = a.y - b.y;
    int r = b.x - a.x;
    int s = c.x * d.y - c.y * d.x;
    int t = c.y - d.y;
    int u = d.x - c.x;

    float x = (float)(r*s-u*p)/(q*u-r*t);
    float y = (float)(q*s-t*p)/(r*t-q*u);

    /*printf*/(
        "crossing of (%d %d)(%d %d) and (%d %d)(%d %d) is: %.2f %.2f\n",
        a, b, c, d,
        (double)x, (double)y
    );

    return {x, y};
}

int dist_sq(point a, point b)
{
    int x = a.x-b.x;
    int y = b.y-a.y;
    return x*x+y*y;
}

float dist_sq(point a, pair<float, float> b)
{
    float x = a.x-b.first;
    float y = b.second-a.y;
    return x*x+y*y;
}

bool is_crossing(point a, point b, point c, point d)
{
    pair<float, float> p = crossing(a, b, c, d);

    bool nada = false;

    nada=
        dist_sq(a, p)>dist_sq(a, b)||dist_sq(b, p)>dist_sq(b, a)||
        dist_sq(c, p)>dist_sq(c, d)||dist_sq(d, p)>dist_sq(d, c);

    return !nada;
}


int n;
vector<point> points;
vector<edge> edges;

bool unique(int a, int b, int c, int d)
{
    return
        a!=b && a!=c && a!=d &&
        b!=c && b!=d &&
        c!=d;
}

bool is_crossing(edge a, edge b)
{
    //if(set<int>{a.a, a.b, b.a, b.b}.size()!=4)return false;
    if(!unique(a.a, a.b, b.a, b.b))return false;

    bool value =  is_crossing(points[a.a], points[a.b], points[b.a], points[b.b]);
    if(value)
    {
        //printf("edges %d->%d and %d->%d are crossing :/\n", a.a, a.b, b.a, b.b);
    }

    return value;
}

void read()
{
    cin>>n;
    points.resize(2*n+1);
    for(int i=1;i<=2*n;i++)cin>>points[i].x>>points[i].y;
}

void merge(vector<vector<int>> &unions, vector<int> &unionOf, int a, int b)
{
    if(unions[a].size()<unions[b].size())
    {
        for(int x : unions[a])
        {
            unionOf[x]=b;
            unions[b].push_back(x);
        }
        unions[a].clear();
    }
    else
    {
        for(int x : unions[b])
        {
            unionOf[x]=a;
            unions[a].push_back(x);
        }
        unions[b].clear();
    }
}

void solve()
{
    for(int i=1;i<=n;i++)
    {
        for(int j=n+1;j<=n*2;j++)edges.emplace_back(i, j, dist_sq(points[i], points[j]));
    }

    sort(edges.begin(), edges.end());
    //for(auto e : edges)printf("%d %d %.2f\n", e);

    vector<vector<int>> unions(n*2+1);
    vector<int> unionOf(n*2+1);

    for(int i=1;i<=2*n;i++)
    {
        unions[i].push_back(i);
        unionOf[i]=i;
    }

    vector<edge> usedEdges;
    for(auto x: edges)
    {
        bool canAdd = unionOf[x.a]!=unionOf[x.b];
        if(!canAdd)continue;
        for(auto y: usedEdges)
        {
            if(is_crossing(x, y)){canAdd=false; break;}
        }
        if(!canAdd)continue;

        merge(unions, unionOf, unionOf[x.a], unionOf[x.b]);
        usedEdges.push_back(x);

        if(usedEdges.size()==n*2-1)break;
    }

    if(usedEdges.size()!=n*2-1)
    {
        puts("-1");
        return;
    }

    printf("%d\n", (int)usedEdges.size());
    for(auto e : usedEdges)printf("%d %d\n", e.a, e.b);
}

int main()
{
    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    //crossing({0, 0}, {1, 1}, {1, 0}, {0, 1});

    read();
    solve();
}
/**
6
6 5
3 3
5 2
7 2
9 5
9 1
5 8
2 4
6 3
8 0
10 4
8 7
**/
