#include <cstdio>
#include <iostream>
#include <vector>
#include <tuple>
#include <algorithm>
#include <set>
#include <deque>
using namespace std;

struct point
{
    int x, y;
    point(int x, int y):x(x), y(y){}
    point():point(0, 0){}
};

pair<float, float> crossing(point a, point b, point c, point d)
{
    int p = a.x * b.y - a.y * b.x;
    int q = a.y - b.y;
    int r = b.x - a.x;
    int s = c.x * d.y - c.y * d.x;
    int t = c.y - d.y;
    int u = d.x - c.x;

    float x = (float)(r*s-u*p)/(q*u-r*t);
    float y = (float)(q*s-t*p)/(r*t-q*u);

    /*printf*/(
        "crossing of (%d %d)(%d %d) and (%d %d)(%d %d) is: %.2f %.2f\n",
        a, b, c, d,
        (double)x, (double)y
    );

    return {x, y};
}

int dist_sq(point a, point b)
{
    int x = a.x-b.x;
    int y = b.y-a.y;
    return x*x+y*y;
}

float dist_sq(point a, pair<float, float> b)
{
    float x = a.x-b.first;
    float y = a.y-b.second;
    return x*x+y*y;
}

bool are_crossing(point a, point b, point c, point d)
{
    pair<float, float> p = crossing(a, b, c, d);

    bool nada = false;

    nada=
        dist_sq(a, p)>dist_sq(a, b)||dist_sq(b, p)>dist_sq(b, a)||
        dist_sq(c, p)>dist_sq(c, d)||dist_sq(d, p)>dist_sq(d, c);

    return !nada;
}

struct edge;

int n, n2;
vector<point> points;
deque<edge> edges;

struct edge
{
    int a, b;

    edge(int a, int b):
        a(a), b(b){}
    edge():edge(0, 0){}

    inline int64_t dist_sq() const
    {
        int64_t x=points[a].x-points[b].x;
        int64_t y=points[a].y-points[b].y;
        return x*x+y*y;
    }

    bool operator < (edge e)const
    {
        return dist_sq() < e.dist_sq();
    }
};

constexpr inline bool unique(int a, int b, int c, int d)
{
    return
        a!=b && a!=c && a!=d &&
        b!=c && b!=d &&
        c!=d;
}

inline bool are_crossing(edge a, edge b)
{
    //if(set<int>{a.a, a.b, b.a, b.b}.size()!=4)return false;
    if(!unique(a.a, a.b, b.a, b.b))return false;

    bool value =  are_crossing(points[a.a], points[a.b], points[b.a], points[b.b]);
    if(value)
    {
        //printf("edges %d->%d and %d->%d are crossing :/\n", a.a, a.b, b.a, b.b);
    }

    return value;
}

void read()
{
    cin>>n;
    n2=n*2;
    points.resize(2*n+1);
    for(int i=1;i<=2*n;i++)cin>>points[i].x>>points[i].y;
}

void merge(vector<vector<int>> &unions, vector<int> &unionOf, int a, int b)
{
    if(a==b)return;
    if(unions[a].size()<unions[b].size())
    {
        unions[b].reserve(unions[b].size() + unions[a].size());
        for(int x : unions[a])
        {
            unionOf[x]=b;
            unions[b].push_back(x);
        }
        unions[a].clear();
        unions[a].shrink_to_fit();
    }
    else
    {
        unions[a].reserve(unions[a].size() + unions[b].size());
        for(int x : unions[b])
        {
            unionOf[x]=a;
            unions[a].push_back(x);
        }
        unions[b].clear();
        unions[b].shrink_to_fit();
    }
}

void solve()
{
    //edges.reserve(n*n);
    for(int i=1;i<=n;i++)
    {
        for(int j=n+1;j<=n2;j++)edges.emplace_back(i, j);
    }

    sort(edges.begin(), edges.end());
    //for(auto e : edges)printf("%d %d %.2f\n", e);

    vector<vector<int>> unions(n2+1);
    vector<int> unionOf(n2+1);

    for(int i=1;i<=2*n;i++)
    {
        unions[i]={i};
        unionOf[i]=i;
    }

    vector<edge> usedEdges;
    usedEdges.reserve(n2);

    //for(auto x: edges)
    while(!edges.empty())
    {
        auto x = edges.front();
        edges.pop_front();
        bool canAdd = unionOf[x.a]!=unionOf[x.b];
        if(!canAdd)continue;
        for(auto y: usedEdges)
        {
            if(are_crossing(x, y)){canAdd=false; break;}
        }
        if(!canAdd)continue;

        merge(unions, unionOf, unionOf[x.a], unionOf[x.b]);
        usedEdges.push_back(x);

        if(usedEdges.size()==n2-1)break;
    }

    if(usedEdges.size()!=n2-1)
    {
        puts("-1");
        return;
    }

    printf("%d\n", (int)usedEdges.size());
    for(auto e : usedEdges)printf("%d %d\n", e.a, e.b);
}

int main()
{

    ios::sync_with_stdio(false);
    cin.tie(nullptr);

    //crossing({0, 0}, {1, 1}, {1, 0}, {0, 1});

    read();
    solve();
}
/**
6
6 5
3 3
5 2
7 2
9 5
9 1
5 8
2 4
6 3
8 0
10 4
8 7
**/
