#include <iostream>
#include <cstdint>
#include <vector>
#include <algorithm> ///Vkluchi algoritmi

const uint32_t MAT = 3;

struct Vector { ///Otnovo Shefa <3
	int64_t v[MAT];
	Vector() {
		for (uint32_t i = 0;i < MAT;i++) {
			v[i] = 0;
		}
	}

	int64_t& operator[] (uint32_t i) {
		return v[i];
	}
	const int64_t& operator[] (uint32_t i) const {
		return v[i];
	}
};

bool operator== (const Vector &a, const Vector &b) {
	for (uint32_t i = 0;i < MAT;i++) {
		if (a[i] != b[i]) {
			return false;
		}
	}
	return true;
}

struct Matrix {
	int64_t m[MAT][MAT];

	Matrix() {
		for (uint32_t i = 0;i < MAT;i++) {
			for (uint32_t j = 0;j < MAT;j++) {
				m[i][j] = 0;
			}
		}
	}

	int64_t* operator[] (uint32_t i) {
		return m[i];
	}
	const int64_t* operator[] (uint32_t i) const {
		return m[i];
	}
};

Matrix operator* (const Matrix &a, const Matrix &b) {
	Matrix ans;
	for (uint32_t i = 0;i < MAT;i++) {
		for (uint32_t j = 0;j < MAT;j++) {
			for (uint32_t k = 0;k < MAT;k++) {
				ans[i][j] += a[i][k] * b[k][j];
			}
		}
	}
	return ans;
}

Vector operator* (const Matrix &m, const Vector &v) {
	Vector ans;
	for (uint32_t i = 0;i < MAT;i++) {
		for (uint32_t j = 0;j < MAT;j++) {
			ans[i] += m[i][j] * v[j];
		}
	}
	return ans;
}

Matrix identity() {
	Matrix ans;
	for (uint32_t i = 0;i < MAT;i++) {
		ans[i][i] = 1;
	}
	return ans;
}

uint32_t trans_code(char c) {
	switch (c) {
	case 'R': return 0;
	case 'L': return 1;
	case 'Q': return 2;
	case 'V': return 3;
	case 'H': return 4;
	}
}

Matrix base_trans[5][2];

void init_base() {
	Matrix m = Matrix();
	m[0][1] = -1;
	m[0][2] = 1;
	m[1][0] = 1;
	m[2][2] = 1;
	base_trans[0][0] = m;

	m = Matrix();
	m[0][1] = 1;
	m[1][0] = -1;
	m[1][2] = 1;
	m[2][2] = 1;
	base_trans[1][0] = m;

	m = Matrix();
	m[0][0] = 1;
	m[1][1] = -1;
	m[1][2] = 1;
	m[2][2] = 1;
	base_trans[3][0] = m;

	m = Matrix();
        m[0][0] = -1;
        m[0][2] = 1;
        m[1][1] = 1;
        m[2][2] = 1;
        base_trans[4][0] = m;

        base_trans[2][0] = base_trans[0][0] * base_trans[0][0];

        base_trans[0][1] = base_trans[1][0];
        base_trans[1][1] = base_trans[0][0];
        base_trans[2][1] = base_trans[2][0];
        base_trans[3][1] = base_trans[3][0];
        base_trans[4][1] = base_trans[4][0];
}

std::vector<Vector> updates;
int64_t n;
Matrix trans = identity();
Matrix rTrans = identity();

void debug_print() {
	for (uint32_t i = 0;i < updates.size();i++) {
		std::cerr << updates[i][1] + 1 << " " << updates[i][0] + 1 << "\n";
	}
	std::cerr << "\n";
}


void change_col(int32_t x, int32_t y) {
	Vector v;
	v[0] = x - 1;
	v[1] = y - 1;
	v[2] = n - 1;
	Vector nv = rTrans * v;
	updates.push_back(nv);
}

void apply_trans(char t) {
	uint32_t c = trans_code(t);
	trans = base_trans[c][0] * trans;
	rTrans = rTrans * base_trans[c][1];
}

void handle_queries() {
	uint32_t q1, q2;
	std::cin >> n >> q1 >> q2;
	for (uint32_t i = 0;i < q1;i++) {
		uint32_t r, c;
		std::cin >> r >> c;
		change_col(c, r);
	}
	//debug_print();
	for (uint32_t i = 0;i < q2;i++) {
		uint32_t t;
		std::cin >> t;
		if (t == 1) {
			char c;
			std::cin >> c;
			apply_trans(c);
		} else {
			uint32_t r, c;
			std::cin >> r >> c;
			change_col(c, r);
			//debug_print();
		}
	}
}

bool vector_cmp(const Vector &a, const Vector &b) {
	if (a[1] != b[1]) {
		return a[1] < b[1];
	} else {
		return a[0] < b[0];
	}

}



void print_ans() {
	for (Vector &v : updates) {
		v = trans * v;
	}

	std::sort(updates.begin(), updates.end(), vector_cmp);
		//debug_print();
	uint32_t bCnt;
	std::cin >> bCnt;
	for (uint32_t i = 0;i < updates.size();i++) {
		uint32_t curC = 0;
		uint32_t j;
		for (j = i;j < updates.size();j++) {
			if (!(updates[j] == updates[i])) {
				break;
			} else {
				curC ^= 1;
			}
		}
		if (curC) {
			std::cout << updates[i][1] + 1 << " " << updates[i][0] + 1 << "\n";
			bCnt--;
			if (bCnt == 0) {
				break;
			}
		}
		i = j - 1;
	}

}

int main() {
	std::ios::sync_with_stdio();
	std::cin.tie(nullptr);

	init_base();
        //trans = rTrans = base_trans[3][0];
        handle_queries();
        print_ans();
}
